===============
DHUB 0.0.4
===============

`DHub` is a dataset storage hub client. It is intended to be a standard tool for hosting and managing Machine Learning datasets.

.. image:: https://travis-ci.org/ipazc/dhub.svg?branch=master
    :target: https://travis-ci.org/ipazc/dhub

This is still a work in progress. It is expected to achieve a Proof Of Concept during October 2017.

=======
LICENSE
=======

It is released under the **GNU GPL v3 or greater** license.
